==> hinemos_agent-4.0.1_rhel4_32.tar.gz: com/clustercontrol/ws/agent/GetMonitorLogfileResponse.java <==

package com.clustercontrol.ws.agent;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import com.clustercontrol.ws.monitor.MonitorInfo;


/**
 * <p>Java class for getMonitorLogfileResponse complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="getMonitorLogfileResponse">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="return" type="{http://monitor.ws.clustercontrol.com}monitorInfo" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "getMonitorLogfileResponse", propOrder = {
    "_return"
})
public class GetMonitorLogfileResponse {

    @XmlElement(name = "return")
    protected List<MonitorInfo> _return;

    /**
     * Gets the value of the return property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the return property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getReturn().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link MonitorInfo }
     * 
     * 
     */
    public List<MonitorInfo> getReturn() {
        if (_return == null) {
            _return = new ArrayList<MonitorInfo>();
        }
        return this._return;
    }

}

==> hinemos_agent-4.1.2_rhel4_64.tar.gz: com/clustercontrol/ws/agent/GetMonitorLogfileResponse.java <==

package com.clustercontrol.ws.agent;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import com.clustercontrol.ws.monitor.MonitorInfo;


/**
 * <p>getMonitorLogfileResponse complex typeのJavaクラス。
 * 
 * <p>次のスキーマ・フラグメントは、このクラス内に含まれる予期されるコンテンツを指定します。
 * 
 * <pre>
 * &lt;complexType name="getMonitorLogfileResponse">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="return" type="{http://monitor.ws.clustercontrol.com}monitorInfo" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "getMonitorLogfileResponse", propOrder = {
    "_return"
})
public class GetMonitorLogfileResponse {

    @XmlElement(name = "return")
    protected List<MonitorInfo> _return;

    /**
     * Gets the value of the return property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the return property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getReturn().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link MonitorInfo }
     * 
     * 
     */
    public List<MonitorInfo> getReturn() {
        if (_return == null) {
            _return = new ArrayList<MonitorInfo>();
        }
        return this._return;
    }

}
